@@ -36,8 +36,5 @@ pub mod keys;
 /// Application banner text.
 pub mod banner;
 
-/// Application splash screen.
-pub mod splash;
-
 /// Utilities.
 pub mod util;
