@@ -3,6 +3,7 @@ use std::process::{Command, Stdio};
 
 /// Runs the given OS command and returns the output lines.
 pub fn run_os_command(cmd: &str) -> Result<Vec<String>> {
+	log::trace!(target: "cmd", "running OS command: {cmd:?}");
 	let child = if cfg!(target_os = "windows") {
 		Command::new("cmd")
 			.args(["/C", cmd])
@@ -19,7 +20,10 @@ pub fn run_os_command(cmd: &str) -> Result<Vec<String>> {
 			let output = child.wait_with_output()?;
 			if output.status.success() {
 				match String::from_utf8(output.stdout) {
-					Ok(s) => Ok(s.lines().map(String::from).collect()),
+					Ok(s) => {
+						log::trace!(target: "cmd", "command output: {s:?}");
+						Ok(s.lines().map(String::from).collect())
+					}
 					Err(e) => Err(anyhow!("UTF-8 error: {:?}", e)),
 				}
 			} else {
