@@ -153,10 +153,10 @@ impl Config {
 	/// Returns the path if the configuration file is found.
 	pub fn get_default_location() -> Option<String> {
 		if let Some(config_dir) = dirs_next::config_dir() {
-			let file_name = format!("{}.toml", env!("CARGO_PKG_NAME"));
+			let file_name = concat!(env!("CARGO_PKG_NAME"), ".toml");
 			for config_file in [
-				config_dir.join(&file_name),
-				config_dir.join(env!("CARGO_PKG_NAME")).join(&file_name),
+				config_dir.join(file_name),
+				config_dir.join(env!("CARGO_PKG_NAME")).join(file_name),
 				config_dir.join(env!("CARGO_PKG_NAME")).join("config"),
 			] {
 				if config_file.exists() {
@@ -183,8 +183,8 @@ impl Config {
 		match self.gpg.as_ref() {
 			Some(gpg) => {
 				args.armor = gpg.armor.unwrap_or_default();
-				args.homedir = gpg.homedir.clone();
-				args.outdir = gpg.outdir.clone();
+				args.homedir.clone_from(&gpg.homedir);
+				args.outdir.clone_from(&gpg.outdir);
 				if let Some(outfile) = &gpg.outfile {
 					args.outfile = outfile.to_string();
 				}
@@ -225,7 +225,7 @@ impl Config {
 						.unwrap_or_default(),
 				);
 				if general.log_file.is_some() {
-					args.log_file = general.log_file.clone();
+					args.log_file.clone_from(&general.log_file);
 				}
 			}
 			None => {
@@ -251,7 +251,7 @@ mod tests {
 	fn test_parse_config() -> Result<()> {
 		let path = PathBuf::from(env!("CARGO_MANIFEST_DIR"))
 			.join("config")
-			.join(format!("{}.toml", env!("CARGO_PKG_NAME")))
+			.join(concat!(env!("CARGO_PKG_NAME"), ".toml"))
 			.to_string_lossy()
 			.into_owned();
 		let mut config = Config::parse_config(&path)?;
